library(tidyverse)
library(rstatix)
library(ggpubr)
library(ggplot2)
library(viridis)
library(scales)
library(dplyr)

#Acetic Acid total D7
Total.Acetic.acid.D7 %>%
  group_by(group) %>%
  get_summary_stats(psyllid, type = "median_iqr")

vis <- ggpaired(Total.Acetic.acid.D7, x = "group" , y ="psyllid",
       order = c("Unbaited", "Acetic Acid"),
       ylab= "No. of psyllids captured", xlab= "Trap type")
vis
#assumpsion check
Assum <- Hori.Acetic.acid.D7 %>% mutate(differences = Acetic_acid - Unbaited)
gghistogram(Assum, x="differences", y= "..density..",
            fill = "steelblue", bins=5, add_density = TRUE)
#sign-ranked test
stat.test <- Total.Acetic.acid.D7 %>%
  wilcox_test(psyllid~group, paired = TRUE) %>%
  add_significance()

stat.test

#ACP total D7
Total.ACP.D7 %>%
  group_by(group) %>%
  get_summary_stats(psyllid, type = "median_iqr")

vis1 <- ggpaired(Total.ACP.D7, x = "group" , y ="psyllid",
                order = c("Unbaited", "ACP"),
                ylab= "No. of psyllids captured", xlab= "Trap type")
vis1

#assumpsion check
Assum <- Hori.ACP.D7 %>% mutate(differences = ACP - Unbaited)
gghistogram(Assum, x="differences", y= "..density..",
            fill = "steelblue", bins=5, add_density = TRUE)

stat.test <- Total.ACP.D7 %>%
  wilcox_test(psyllid~group, paired = TRUE) %>%
  add_significance()

stat.test

#Ethyl butyrate total D7
Total.Ethyl.butyrate.D7 %>%
  group_by(group) %>%
  get_summary_stats(psyllid, type = "median_iqr")

vis2 <- ggpaired(Total.Ethyl.butyrate.D7, x = "group" , y ="psyllid",
                 order = c("Unbaited", "Ethyl butyrate"),
                 ylab= "No. of psyllids captured", xlab= "Trap type")
vis2

#assumpsion check
Assum <- Hori.Ethyl.butyrate.D7 %>% mutate(differences = Ethyl_butyrate - Unbaited)
gghistogram(Assum, x="differences", y= "..density..",
            fill = "steelblue", bins=5, add_density = TRUE)

stat.test <- Total.Ethyl.butyrate.D7 %>%
  wilcox_test(psyllid~group, paired = TRUE) %>%
  add_significance()

stat.test

#Hexane total D3
Total.Hexane.D7 %>%
  group_by(group) %>%
  get_summary_stats(psyllid, type = "median_iqr")

vis3 <- ggpaired(Total.Hexane.D7, x = "group" , y ="psyllid",
                 order = c("Unbaited", "Hexane"),
                 ylab= "No. of psyllids captured", xlab= "Trap type")
vis3

#assumpsion check
Assum <- Hori.Hexane.D7 %>% mutate(differences = Hexane - Unbaited)
gghistogram(Assum, x="differences", y= "..density..",
            fill = "steelblue", bins=5, add_density = TRUE)

stat.test <- Total.Hexane.D7 %>%
  wilcox_test(psyllid~group,paired = TRUE) %>%
  add_significance()

stat.test

#Limonene total D7
Total.Limonene.D7 %>%
  group_by(group) %>%
  get_summary_stats(psyllid, type = "median_iqr")

vis4 <- ggpaired(Total.Limonene.D7, x = "group" , y ="psyllid",
                 order = c("Unbaited", "Limonene"),
                 ylab= "No. of psyllids captured", xlab= "Trap type")
vis4

#assumpsion check
Assum <- Hori.Limonene.D7 %>% mutate(differences = Limonene - Unbaited)
gghistogram(Assum, x="differences", y= "..density..",
            fill = "steelblue", bins=5, add_density = TRUE)

stat.test <- Total.Limonene.D7 %>%
  wilcox_test(psyllid~group, paired = TRUE) %>%
  add_significance()

stat.test

#Methyl salicylate total D7
Total.Methyl.salicylate.D7 %>%
  group_by(group) %>%
  get_summary_stats(psyllid, type = "median_iqr")

vis5 <- ggpaired(Total.Methyl.salicylate.D7, x = "group" , y ="psyllid",
                 order = c("Unbaited", "Methyl salicylate"),
                 ylab= "No. of psyllids captured", xlab= "Trap type")
vis5

#assumpsion check
Assum <- Hori.Methyl.salicylate.D7 %>% mutate(differences = Methyl_salicylate - Unbaited)
gghistogram(Assum, x="differences", y= "..density..",
            fill = "steelblue", bins=5, add_density = TRUE)

stat.test <- Total.Methyl.salicylate.D7 %>%
  wilcox_test(psyllid~group,paired = TRUE) %>%
  add_significance()

stat.test

#Myrcene total D7
Total.Myrcene.D7 %>%
  group_by(group) %>%
  get_summary_stats(psyllid, type = "median_iqr")

vis6 <- ggpaired(Total.Myrcene.D7, x = "group" , y ="psyllid",
                 order = c("Unbaited", "Myrcene"),
                 ylab= "No. of psyllids captured", xlab= "Trap type")
vis6


#assumpsion check
Assum <- Hori.Myrcene.D7 %>% mutate(differences = Myrcene - Unbaited)
gghistogram(Assum, x="differences", y= "..density..",
            fill = "steelblue", bins=5, add_density = TRUE)

stat.test <- Total.Myrcene.D7 %>%
  wilcox_test(psyllid~group, paired = TRUE) %>%
  add_significance()

stat.test

#Ocimene total D7
Total.Ocimene.D7 %>%
  group_by(group) %>%
  get_summary_stats(psyllid, type = "median_iqr")

vis7 <- ggpaired(Total.Ocimene.D7, x = "group" , y ="psyllid",
                order = c("Unbaited", "Ocimene"),
                ylab= "No. of psyllids captured", xlab= "Trap type")
vis7

#assumpsion check
Assum <- Hori.Ocimene.D7 %>% mutate(differences = Ocimene - Unbaited)
gghistogram(Assum, x="differences", y= "..density..",
            fill = "steelblue", bins=5, add_density = TRUE)

stat.test2 <- Total.Ocimene.D7 %>%
  wilcox_test(psyllid~group, paired = TRUE) %>%
  add_significance()

stat.test2

#p.Cymene total D7
Total.p.Cymene.D7 %>%
  group_by(group) %>%
  get_summary_stats(psyllid, type = "median_iqr")

vis8 <- ggpaired(Total.p.Cymene.D7, x = "group" , y ="psyllid",
                 order = c("Unbaited", "p-Cymene"),
                 ylab= "No. of psyllids captured", xlab= "Trap type")
vis8

#assumpsion check
Assum <- Hori.p.Cymene.D7 %>% mutate(differences = Cymene - Unbaited)
gghistogram(Assum, x="differences", y= "..density..",
            fill = "steelblue", bins=5, add_density = TRUE)

stat.test <- Total.p.Cymene.D7 %>%
  wilcox_test(psyllid~group, paired = TRUE) %>%
  add_significance()

stat.test

#Sabinene total D7
Total.Sabinene.D7 %>%
  group_by(group) %>%
  get_summary_stats(psyllid, type = "median_iqr")

vis9 <- ggpaired(Total.Sabinene.D7, x = "group" , y ="psyllid",
                 order = c("Unbaited", "Sabinene"),
                 ylab= "No. of psyllids captured", xlab= "Trap type")
vis9

#assumpsion check
Assum <- Hori.Sabinene.D7 %>% mutate(differences = Sabinene - Unbaited)
gghistogram(Assum, x="differences", y= "..density..",
            fill = "steelblue", bins=5, add_density = TRUE)

stat.test <- Total.Sabinene.D7 %>%
  wilcox_test(psyllid~group, paired = TRUE) %>%
  add_significance()

stat.test


